@@ -5,18 +5,17 @@ Manage backend sender.
 
 """
 
-import six
-import json
-from six.moves import queue
-import logging
 from datetime import date, datetime
-import time
-from wandb.data import data_types
-
-from wandb.proto import wandb_internal_pb2  # type: ignore
-from wandb.interface import constants
+import json
+import logging
 
 import numpy as np  # type: ignore
+import six
+from six.moves import queue
+import wandb
+from wandb import data_types
+from wandb.interface import constants
+from wandb.proto import wandb_internal_pb2  # type: ignore
 
 logger = logging.getLogger("wandb")
 
@@ -27,24 +26,30 @@ def is_numpy_array(obj):
 
 def is_tf_tensor(obj):
     import tensorflow  # type: ignore
+
     return isinstance(obj, tensorflow.Tensor)
 
 
 def is_tf_tensor_typename(typename):
-    return typename.startswith('tensorflow.') and ('Tensor' in typename or 'Variable' in typename)
+    return typename.startswith("tensorflow.") and (
+        "Tensor" in typename or "Variable" in typename
+    )
 
 
 def is_tf_eager_tensor_typename(typename):
-    return typename.startswith('tensorflow.') and ('EagerTensor' in typename)
+    return typename.startswith("tensorflow.") and ("EagerTensor" in typename)
 
 
 def is_pytorch_tensor(obj):
-    import torch
+    import torch  # type: ignore
+
     return isinstance(obj, torch.Tensor)
 
 
 def is_pytorch_tensor_typename(typename):
-    return typename.startswith('torch.') and ('Tensor' in typename or 'Variable' in typename)
+    return typename.startswith("torch.") and (
+        "Tensor" in typename or "Variable" in typename
+    )
 
 
 def get_full_typename(o):
@@ -65,7 +70,7 @@ def get_h5_typename(o):
     elif is_pytorch_tensor_typename(typename):
         return "torch.Tensor"
     else:
-        return o.__class__.__module__.split('.')[0] + "." + o.__class__.__name__
+        return o.__class__.__module__.split(".")[0] + "." + o.__class__.__name__
 
 
 def json_friendly(obj):
@@ -101,31 +106,35 @@ def json_friendly(obj):
     elif np and isinstance(obj, np.generic):
         obj = obj.item()
     elif isinstance(obj, bytes):
-        obj = obj.decode('utf-8')
+        obj = obj.decode("utf-8")
     elif isinstance(obj, (datetime, date)):
         obj = obj.isoformat()
     else:
         converted = False
-    #if getsizeof(obj) > VALUE_BYTES_LIMIT:
-    #    wandb.termwarn("Serializing object of type {} that is {} bytes".format(type(obj).__name__, getsizeof(obj)))
+    # if getsizeof(obj) > VALUE_BYTES_LIMIT:
+    #    wandb.termwarn("Serializing object of type {} that is {} bytes".format(
+    #                   type(obj).__name__, getsizeof(obj)))
 
     return obj, converted
 
 
 def maybe_compress_summary(obj, h5_typename):
     if np and isinstance(obj, np.ndarray) and obj.size > 32:
-        return {
-            "_type": h5_typename,  # may not be ndarray
-            "var": np.var(obj).item(),
-            "mean": np.mean(obj).item(),
-            "min": np.amin(obj).item(),
-            "max": np.amax(obj).item(),
-            "10%": np.percentile(obj, 10),
-            "25%": np.percentile(obj, 25),
-            "75%": np.percentile(obj, 75),
-            "90%": np.percentile(obj, 90),
-            "size": obj.size
-        }, True
+        return (
+            {
+                "_type": h5_typename,  # may not be ndarray
+                "var": np.var(obj).item(),
+                "mean": np.mean(obj).item(),
+                "min": np.amin(obj).item(),
+                "max": np.amax(obj).item(),
+                "10%": np.percentile(obj, 10),
+                "25%": np.percentile(obj, 25),
+                "75%": np.percentile(obj, 75),
+                "90%": np.percentile(obj, 90),
+                "size": obj.size,
+            },
+            True,
+        )
     else:
         return obj, False
 
@@ -134,7 +143,7 @@ class WandBJSONEncoder(json.JSONEncoder):
     """A JSON Encoder that handles some extra types."""
 
     def default(self, obj):
-        if hasattr(obj, 'json_encode'):
+        if hasattr(obj, "json_encode"):
             return obj.json_encode()
         # if hasattr(obj, 'to_json'):
         #     return obj.to_json()
@@ -149,8 +158,7 @@ class WandBJSONEncoderOld(json.JSONEncoder):
 
     def default(self, obj):
         tmp_obj, converted = json_friendly(obj)
-        tmp_obj, compressed = maybe_compress_summary(
-            tmp_obj, get_h5_typename(obj))
+        tmp_obj, compressed = maybe_compress_summary(tmp_obj, get_h5_typename(obj))
         if converted:
             return tmp_obj
         return json.JSONEncoder.default(self, tmp_obj)
@@ -162,6 +170,7 @@ def maybe_compress_history(obj):
     else:
         return obj, False
 
+
 def json_dumps_safer_history(obj, **kwargs):
     """Convert obj to json, with some extra encodable types, including histograms"""
     return json.dumps(obj, cls=WandBHistoryJSONEncoder, **kwargs)
@@ -180,52 +189,62 @@ class WandBHistoryJSONEncoder(json.JSONEncoder):
 
 
 class BackendSender(object):
-
     class ExceptionTimeout(Exception):
         pass
 
-    def __init__(self, process_queue=None, notify_queue=None, request_queue=None, response_queue=None):
+    def __init__(
+        self,
+        process_queue=None,
+        notify_queue=None,
+        request_queue=None,
+        response_queue=None,
+        process=None,
+    ):
         self.process_queue = process_queue
         self.notify_queue = notify_queue
         self.request_queue = request_queue
         self.response_queue = response_queue
         self._run = None
+        self._process = process
 
     def _hack_set_run(self, run):
         self._run = run
 
     def send_output(self, name, data):
         # from vendor.protobuf import google3.protobuf.timestamp
-        #ts = timestamp.Timestamp()
-        #ts.GetCurrentTime()
-        #now = datetime.now()
+        # ts = timestamp.Timestamp()
+        # ts.GetCurrentTime()
+        # now = datetime.now()
         if name == "stdout":
             otype = wandb_internal_pb2.OutputData.OutputType.STDOUT
         elif name == "stderr":
             otype = wandb_internal_pb2.OutputData.OutputType.STDERR
         else:
-            # FIXME: throw error?
+            # TODO(jhr): throw error?
             print("unknown type")
-        o = wandb_internal_pb2.OutputData(output_type=otype, str=data)
+        o = wandb_internal_pb2.OutputData(output_type=otype, line=data)
         o.timestamp.GetCurrentTime()
         rec = wandb_internal_pb2.Record()
         rec.output.CopyFrom(o)
-        self.process_queue.put(rec)
-        self.notify_queue.put(constants.NOTIFY_PROCESS)
+        self._queue_process(rec)
 
-    def send_log(self, data):
-        data = data_types.history_dict_to_json(self._run, data)
-        json_data = json_dumps_safer_history(data)
-        #json_data = json.dumps(data)
-        l = wandb_internal_pb2.LogData(json=json_data)
+    def send_history(self, data):
         rec = wandb_internal_pb2.Record()
-        rec.log.CopyFrom(l)
-        self.process_queue.put(rec)
-        self.notify_queue.put(constants.NOTIFY_PROCESS)
+        data = data_types.history_dict_to_json(self._run, data)
+        history = rec.history
+        for k, v in six.iteritems(data):
+            item = history.item.add()
+            item.key = k
+            item.value_json = json_dumps_safer_history(v)
+        self._queue_process(rec)
 
     def _make_run(self, run):
-        proto_run = wandb_internal_pb2.Run()
+        proto_run = wandb_internal_pb2.RunData()
         run._make_proto_run(proto_run)
+        proto_run.start_time.GetCurrentTime()
+        if run._config is not None:
+            config_dict = run._config._as_dict()
+            self._make_config(config_dict, obj=proto_run.config)
         return proto_run
 
     def _make_exit(self, exit_code):
@@ -233,16 +252,22 @@ class BackendSender(object):
         exit.exit_code = exit_code
         return exit
 
-    def _make_config(self, config_dict):
-        config = wandb_internal_pb2.ConfigData()
-        config.run_id = config_dict['run_id']
-        config.config_json = json.dumps(config_dict['data'])
+    def _make_config(self, config_dict, obj=None):
+        config = obj or wandb_internal_pb2.ConfigData()
+        for k, v in six.iteritems(config_dict):
+            update = config.update.add()
+            update.key = k
+            update.value_json = json.dumps(v)
         return config
 
     def _make_stats(self, stats_dict):
         stats = wandb_internal_pb2.StatsData()
-        #config.run_id = config_dict['run_id']
-        stats.stats_json = json.dumps(stats_dict['data'])
+        stats.stats_type = wandb_internal_pb2.StatsData.StatsType.SYSTEM
+        stats.timestamp.GetCurrentTime()
+        for k, v in six.iteritems(stats_dict):
+            item = stats.item.add()
+            item.key = k
+            item.value_json = json.dumps(v)
         return stats
 
     def _summary_encode(self, value, path_from_root):
@@ -267,30 +292,38 @@ class BackendSender(object):
             return json_value
         else:
             path = ".".join(path_from_root)
-            friendly_value, converted = json_friendly(data_types.val_to_json(self._run, path, value))
-            json_value, compressed = maybe_compress_summary(friendly_value, get_h5_typename(value))
+            friendly_value, converted = json_friendly(
+                data_types.val_to_json(self._run, path, value)
+            )
+            json_value, compressed = maybe_compress_summary(
+                friendly_value, get_h5_typename(value)
+            )
             if compressed:
-                self.write_h5(path_from_root, friendly_value)
+                # TODO(jhr): impleement me
+                pass
+                # self.write_h5(path_from_root, friendly_value)
 
             return json_value
 
     def _make_summary(self, summary_dict):
-        data = summary_dict['data']
-        data = self._summary_encode(data, tuple())
-        json_data = json.dumps(data, cls=WandBJSONEncoderOld)
+        data = self._summary_encode(summary_dict, tuple())
         summary = wandb_internal_pb2.SummaryData()
-        summary.run_id = summary_dict['run_id']
-        summary.summary_json = json_data
+        for k, v in six.iteritems(data):
+            update = summary.update.add()
+            update.key = k
+            update.value_json = json.dumps(v, cls=WandBJSONEncoderOld)
         return summary
 
     def _make_files(self, files_dict):
         files = wandb_internal_pb2.FilesData()
-        for path in files_dict['files']:
+        for path in files_dict["files"]:
             f = files.files.add()
-            f.name = path
+            f.path[:] = path
         return files
 
-    def _make_record(self, run=None, config=None, files=None, summary=None, stats=None, exit=None):
+    def _make_record(
+        self, run=None, config=None, files=None, summary=None, stats=None, exit=None
+    ):
         rec = wandb_internal_pb2.Record()
         if run:
             rec.run.CopyFrom(run)
@@ -307,6 +340,8 @@ class BackendSender(object):
         return rec
 
     def _queue_process(self, rec):
+        if self._process and not self._process.is_alive():
+            raise Exception("problem")
         self.process_queue.put(rec)
         self.notify_queue.put(constants.NOTIFY_PROCESS)
 
@@ -328,7 +363,8 @@ class BackendSender(object):
             rsp = self.response_queue.get(timeout=timeout)
         except queue.Empty:
             self._request_flush()
-            raise BackendSender.ExceptionTimeout("timeout")
+            # raise BackendSender.ExceptionTimeout("timeout")
+            return None
 
         # returns response, err
         return rsp
